---
feature_story: FS_72_53_55_13
feature_title: show non-default options
feature_status: TODO
---

FS_72_40_53_00 fill control automatically sets default values (possibly based on some logic)<br/>
and these values are never interrogated.

However, user still needs to know what are all other non-default options before default is picked.<br/>
These options should be shown by `query_enum_items_func` FS_02_25_41_81 command.

